@@ -576,8 +576,8 @@ class AssociationLN(ic.COSEMInterfaceClasses):
     through instances of the “Association LN” class. A COSEM logical device has one instance of this IC for each association
     the device is able to support"""
     NAME = cn.ASSOCIATION_LN
-    CLASS_ID = ut.CosemClassId(class_id.ASSOCIATION_LN_CLASS)
-    VERSION = cdt.Unsigned(0)
+    CLASS_ID = ClassID.ASSOCIATION_LN_CLASS
+    VERSION = Version.V0
     __cb_get_attr_descriptor: Callable[[int], ut.CosemAttributeDescriptor | ut.CosemAttributeDescriptorWithSelection]
     A_ELEMENTS = (ic.ICAElement(an.OBJECT_LIST, ObjectListType, selective_access=SelectiveAccessDescriptor),
                   ic.ICAElement(an.ASSOCIATED_PARTNERS_ID, AssociatedPartnersType),
@@ -599,7 +599,8 @@ class AssociationLN(ic.COSEMInterfaceClasses):
         self.set_attr(5, None)
         self.set_attr(8, None)
         # init secret after set authentication_mechanism_name(6)
-        self._cbs_attr_post_init.update({6: self.__init_secret,
+        self._cbs_attr_post_init.update({5: self.__set_dlms_version_to_collection,
+                                         6: self.__init_secret,
                                          7: self.__check_mechanism_id_existing})
         # set cb change client SAP
         match self.logical_name.e:
@@ -666,6 +667,9 @@ class AssociationLN(ic.COSEMInterfaceClasses):
             case unknown:                                                  raise ValueError(F'Not support Secret with {unknown}')
         print(F'set secret class {self}, REMOVE it message')
 
+    def __set_dlms_version_to_collection(self):
+        self.collection.dlms_ver = int(self.xDLMS_context_info.dlms_version_number)
+
     @property
     def objects(self) -> list[ic.COSEMInterfaceClasses]:
         """ get all DLMS object in association"""
